#ifndef NT2_INCLUDE_FUNCTIONS_REMAINDER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REMAINDER_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/remainder.hpp>

#endif
